<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="20"/>
        <location filename="../mainwindow.cpp" line="92"/>
        <source>MX Package Installer</source>
        <translation>MX Namestitev paketov</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="57"/>
        <source>Popular Applications</source>
        <translation>Priljubljeni programi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="83"/>
        <location filename="../mainwindow.cpp" line="95"/>
        <source>Package</source>
        <translation>Paket</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="88"/>
        <location filename="../mainwindow.cpp" line="95"/>
        <source>Info</source>
        <translation>Informacije</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="93"/>
        <location filename="../mainwindow.ui" line="250"/>
        <location filename="../mainwindow.ui" line="660"/>
        <location filename="../mainwindow.ui" line="989"/>
        <location filename="../mainwindow.cpp" line="95"/>
        <source>Description</source>
        <translation>Opis</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="113"/>
        <location filename="../mainwindow.ui" line="216"/>
        <location filename="../mainwindow.ui" line="626"/>
        <location filename="../mainwindow.ui" line="958"/>
        <location filename="../mainwindow.ui" line="1233"/>
        <source>search</source>
        <translation>iskanje</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="123"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Manage popular packages&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Greyed out items have already been installed.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Upravljanje priljubljenih paktov&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Sivo obarvani paketi so že bili nameščeni.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="153"/>
        <source>Stable Repo</source>
        <translation>Stabilni repo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="174"/>
        <location filename="../mainwindow.ui" line="571"/>
        <location filename="../mainwindow.ui" line="903"/>
        <location filename="../mainwindow.ui" line="1181"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Filter packages according to their status.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Filtriranje paketov glede na njihovo status.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="177"/>
        <location filename="../mainwindow.ui" line="181"/>
        <location filename="../mainwindow.ui" line="574"/>
        <location filename="../mainwindow.ui" line="578"/>
        <location filename="../mainwindow.ui" line="906"/>
        <location filename="../mainwindow.ui" line="910"/>
        <location filename="../mainwindow.cpp" line="2415"/>
        <source>All packages</source>
        <translation>Vsi paketi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="186"/>
        <location filename="../mainwindow.ui" line="583"/>
        <location filename="../mainwindow.ui" line="915"/>
        <location filename="../mainwindow.cpp" line="2429"/>
        <source>Installed</source>
        <translation>Nameščeno</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="191"/>
        <location filename="../mainwindow.ui" line="588"/>
        <location filename="../mainwindow.ui" line="920"/>
        <location filename="../mainwindow.cpp" line="2427"/>
        <source>Upgradable</source>
        <translation>Nadgradljivo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="196"/>
        <location filename="../mainwindow.ui" line="593"/>
        <location filename="../mainwindow.ui" line="925"/>
        <location filename="../mainwindow.ui" line="1213"/>
        <location filename="../mainwindow.cpp" line="2394"/>
        <location filename="../mainwindow.cpp" line="2431"/>
        <location filename="../mainwindow.cpp" line="2521"/>
        <source>Not installed</source>
        <translation>Ni nameščeno</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="240"/>
        <location filename="../mainwindow.ui" line="650"/>
        <location filename="../mainwindow.ui" line="979"/>
        <source>Package Name</source>
        <translation>Ime paketa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="245"/>
        <location filename="../mainwindow.ui" line="655"/>
        <location filename="../mainwindow.ui" line="984"/>
        <location filename="../mainwindow.ui" line="1268"/>
        <source>Version</source>
        <translation>Različica</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="277"/>
        <location filename="../mainwindow.ui" line="687"/>
        <location filename="../mainwindow.ui" line="1046"/>
        <source>Total packages:</source>
        <translation>Skupaj paketov:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="354"/>
        <location filename="../mainwindow.ui" line="737"/>
        <location filename="../mainwindow.ui" line="1025"/>
        <source>Installed:</source>
        <translation>Nameščenih:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="384"/>
        <location filename="../mainwindow.ui" line="767"/>
        <location filename="../mainwindow.ui" line="1018"/>
        <source>Upgradable:</source>
        <translation>Nadgradljivih:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="291"/>
        <location filename="../mainwindow.ui" line="1338"/>
        <source>Upgrade All</source>
        <translation>Nadgradi vse</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="318"/>
        <location filename="../mainwindow.ui" line="701"/>
        <location filename="../mainwindow.ui" line="1053"/>
        <source>Hide library and developer packages</source>
        <translation>Skrij knjižnice in razvojne pakete</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="340"/>
        <location filename="../mainwindow.ui" line="723"/>
        <location filename="../mainwindow.ui" line="1105"/>
        <source>Refresh list</source>
        <translation>Osveži seznam</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="414"/>
        <location filename="../mainwindow.ui" line="794"/>
        <location filename="../mainwindow.ui" line="1086"/>
        <source>Also Install &quot;Recommended&quot; Packages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="424"/>
        <location filename="../mainwindow.ui" line="601"/>
        <location filename="../mainwindow.ui" line="933"/>
        <location filename="../mainwindow.ui" line="1494"/>
        <source>Greyed out items have already been installed.</source>
        <translation>Osiveli paketi so že bili nameščeni.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="480"/>
        <location filename="../mainwindow.ui" line="543"/>
        <location filename="../mainwindow.ui" line="870"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;= Upgradable package. Newer version available in selected repository.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;= nadgradljiv paket. V izbranem repozitoriju je na voljo novejša različica.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="500"/>
        <source>MX Test Repo</source>
        <translation>MX testni repozitorij</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="827"/>
        <source>Debian Backports</source>
        <translation>Debian backporti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1160"/>
        <source>Flatpaks</source>
        <translation>Flatpaks</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1184"/>
        <location filename="../mainwindow.ui" line="1188"/>
        <location filename="../mainwindow.cpp" line="2376"/>
        <location filename="../mainwindow.cpp" line="2516"/>
        <source>All apps</source>
        <translation>Vsi programi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1193"/>
        <location filename="../mainwindow.cpp" line="2380"/>
        <source>All runtimes</source>
        <translation>Vse izvršljivo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1198"/>
        <location filename="../mainwindow.cpp" line="2385"/>
        <source>All available</source>
        <translation>Vse, kar je na voljo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1203"/>
        <location filename="../mainwindow.cpp" line="2374"/>
        <location filename="../mainwindow.cpp" line="2517"/>
        <source>Installed apps</source>
        <translation>Nameščeni programi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1208"/>
        <location filename="../mainwindow.cpp" line="2372"/>
        <source>Installed runtimes</source>
        <translation>Nameščeno izvršljivo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1258"/>
        <source>Short Name</source>
        <translation>Kratko ime</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1263"/>
        <source>Full Package Name</source>
        <translation>Polno ime paketa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1273"/>
        <source>Size</source>
        <translation>Velikost</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1317"/>
        <source>Total items </source>
        <translation>Skupaj enot</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1331"/>
        <source>Installed apps:</source>
        <translation>Nameščeni programi:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1384"/>
        <source>Advanced</source>
        <translation>Napredno</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1414"/>
        <source>Total installed size:</source>
        <translation>Skupna velikost namestitve:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1428"/>
        <source>Remove unused runtimes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1444"/>
        <location filename="../mainwindow.ui" line="1448"/>
        <source>For all users</source>
        <translation>Za vse uporabnike</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1453"/>
        <source>For current user</source>
        <translation>Za trenutnega uporabnika</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1471"/>
        <source>Remote (repo):</source>
        <translation>Oddaljeno (repo):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1514"/>
        <location filename="../mainwindow.cpp" line="2196"/>
        <location filename="../mainwindow.cpp" line="2329"/>
        <source>Console Output</source>
        <translation>Izpis na konzoli</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1520"/>
        <source>Enter</source>
        <translation>Enter</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1531"/>
        <source>Respond here, or just press Enter</source>
        <translation>Odzovite se tukaj ali zgolj pritisnite Enter</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1587"/>
        <source>Uninstall</source>
        <translation>Odstrani</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1594"/>
        <source>Alt+U</source>
        <translation>Alt+U</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1610"/>
        <source>About this application</source>
        <translation>O tem programu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1613"/>
        <source>About...</source>
        <translation>O programu...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1620"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1668"/>
        <source>Display help </source>
        <translation>Prikaži pomoč</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1671"/>
        <source>Help</source>
        <translation>Pomoč</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1678"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1694"/>
        <location filename="../mainwindow.cpp" line="1056"/>
        <location filename="../mainwindow.cpp" line="2511"/>
        <location filename="../mainwindow.cpp" line="2514"/>
        <location filename="../mainwindow.cpp" line="2782"/>
        <source>Install</source>
        <translation>Namesti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1701"/>
        <source>Alt+I</source>
        <translation>Alt+I</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1720"/>
        <source>Quit application</source>
        <translation>Zapri aplikacijo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1723"/>
        <source>Close</source>
        <translation>Zapri</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1730"/>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="172"/>
        <source>Uninstalling packages...</source>
        <translation>Odstranjevanje paketov</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="177"/>
        <source>Running pre-uninstall operations...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="190"/>
        <source>Running post-uninstall operations...</source>
        <translation>Izvajam operacije po namestitvi...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="209"/>
        <source>Refreshing sources...</source>
        <translation>Osvežujem vire...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="222"/>
        <location filename="../mainwindow.cpp" line="1095"/>
        <location filename="../mainwindow.cpp" line="1219"/>
        <location filename="../mainwindow.cpp" line="1351"/>
        <location filename="../mainwindow.cpp" line="1409"/>
        <location filename="../mainwindow.cpp" line="2016"/>
        <location filename="../mainwindow.cpp" line="2043"/>
        <location filename="../mainwindow.cpp" line="2053"/>
        <location filename="../mainwindow.cpp" line="2169"/>
        <location filename="../mainwindow.cpp" line="2187"/>
        <location filename="../mainwindow.cpp" line="2600"/>
        <location filename="../mainwindow.cpp" line="2675"/>
        <location filename="../mainwindow.cpp" line="2702"/>
        <location filename="../mainwindow.cpp" line="2804"/>
        <source>Error</source>
        <translation>Napaka</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="222"/>
        <source>There was a problem updating sources. Some sources may not have provided updates. For more info check: </source>
        <translation>Prišlo je do težav pri osveževanju virov. Nekateri viri morda niso pravilno podali posodobitev. Za več informacij preveri:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="608"/>
        <source>Cancel</source>
        <translation>Prekini</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="614"/>
        <source>Please wait...</source>
        <translation>Prosimo, počakajt...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="808"/>
        <location filename="../mainwindow.cpp" line="825"/>
        <source>Version </source>
        <translation>Različica</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="808"/>
        <source> in stable repo</source>
        <translation>v stabilnem repozitoriju</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="810"/>
        <source>Not available in stable repo</source>
        <translation>Ni na voljo v stabilnem repozitoriju</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="819"/>
        <location filename="../mainwindow.cpp" line="2309"/>
        <source>Latest version </source>
        <translation>Zadnja različica</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="819"/>
        <location filename="../mainwindow.cpp" line="2309"/>
        <source> already installed</source>
        <translation>je že nameščena</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="825"/>
        <source> installed</source>
        <translation>nameščena</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="934"/>
        <source>You are about to use the MX Test repository, whose packages are provided for testing purposes only. It is possible that they might break your system, so it is suggested that you back up your system and install or update only one package at a time. Please provide feedback in the Forum so the package can be evaluated before moving up to Main.</source>
        <translation>Ste na tem, da bi uporabljali testne repozitorije, katerih paketi so namenjeni zgolj testiranju. Obstaja možnost, da bodo ti pokvarili vaš sistem, zato svetujemo, da naredite varnostno kopijo svojega sistema in da naenkrat namestite ali posodobite le po en paket. Prosimo, da posredujete povratne informacije na forumu, zato da bo lahko paket ovrednosten in prestavljen v glavni repozitorij.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="943"/>
        <source>You are about to use Debian Backports, which contains packages taken from the next Debian release (called &apos;testing&apos;), adjusted and recompiled for usage on Debian stable. They cannot be tested as extensively as in the stable releases of Debian and MX Linux, and are provided on an as-is basis, with risk of incompatibilities with other components in Debian stable. Use with care!</source>
        <translation>Ste na tem, da boste uporabili Debian backporte, ki vsebujejo pakete iz naslednjih izdaj Debiana (poimenovano &apos;testing&apos;) in ki so prilagojeni za rabo s stabilnim Debianom. Niso preizkušeni tako intenzivno, kot stabilne izdaje za Debian ali MX Linux in so lahko nezdružljivi z drugimi komponentami stabilnega Debiana. Uporabite previdno!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="951"/>
        <source>MX Linux includes this repository of flatpaks for the users&apos; convenience only, and is not responsible for the functionality of the individual flatpaks themselves. For more, consult flatpaks in the Wiki.</source>
        <translation>MX Linux vsebuje ta repozitorij s flatpaki zgolj zato, da bi ustregel določenim uporabnikom in ni odgovoren za njihovo funkcionalnost. Za več informacij preverite flatpaks Wiki.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="959"/>
        <source>Warning</source>
        <translation>Opozorilo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="963"/>
        <source>Do not show this message again</source>
        <translation>Ne prikaži več tega sporočila.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1054"/>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1068"/>
        <source>The following packages were selected. Click Show Details for list of changes.</source>
        <translation>Izbrani so bili naslednji paketi. Za prikaz sprememb kliknite Prikaži podrobnosti.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1095"/>
        <location filename="../mainwindow.cpp" line="1219"/>
        <location filename="../mainwindow.cpp" line="1409"/>
        <source>Internet is not available, won&apos;t be able to download the list of packages</source>
        <translation>Ni povezave s spletom, zato ni mogoče naložiti seznama paketov</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1100"/>
        <source>Installing packages...</source>
        <translation>Nameščanje paketov...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1150"/>
        <source>Post-processing...</source>
        <translation>Po-procesiranje...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1181"/>
        <source>Pre-processing for </source>
        <translation>Pred-procesiranje...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1194"/>
        <source>Installing </source>
        <translation>Nameščanje</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1201"/>
        <source>Post-processing for </source>
        <translation>Po-procesiranje za</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1351"/>
        <source>There was an error writing file: %1. Please check if you have enough free space on your drive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1417"/>
        <source>Downloading package info...</source>
        <translation>Prenašanje informacij o paketu...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1846"/>
        <source>Packages to be installed: </source>
        <translation>Paketi, ki bodo nameščeni:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1880"/>
        <location filename="../mainwindow.cpp" line="1896"/>
        <source>Package info</source>
        <translation>Informacije o paketu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2012"/>
        <location filename="../mainwindow.cpp" line="2024"/>
        <location filename="../mainwindow.cpp" line="2037"/>
        <location filename="../mainwindow.cpp" line="2050"/>
        <location filename="../mainwindow.cpp" line="2143"/>
        <location filename="../mainwindow.cpp" line="2164"/>
        <location filename="../mainwindow.cpp" line="2596"/>
        <location filename="../mainwindow.cpp" line="2669"/>
        <location filename="../mainwindow.cpp" line="2696"/>
        <location filename="../mainwindow.cpp" line="2798"/>
        <source>Done</source>
        <translation>Zaključeno</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2012"/>
        <location filename="../mainwindow.cpp" line="2024"/>
        <location filename="../mainwindow.cpp" line="2037"/>
        <location filename="../mainwindow.cpp" line="2050"/>
        <location filename="../mainwindow.cpp" line="2143"/>
        <location filename="../mainwindow.cpp" line="2164"/>
        <location filename="../mainwindow.cpp" line="2181"/>
        <location filename="../mainwindow.cpp" line="2596"/>
        <location filename="../mainwindow.cpp" line="2669"/>
        <location filename="../mainwindow.cpp" line="2696"/>
        <location filename="../mainwindow.cpp" line="2798"/>
        <source>Processing finished successfully.</source>
        <translation>Procesiranje je bilo uspešno zaključeno.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2016"/>
        <location filename="../mainwindow.cpp" line="2043"/>
        <location filename="../mainwindow.cpp" line="2053"/>
        <location filename="../mainwindow.cpp" line="2600"/>
        <location filename="../mainwindow.cpp" line="2675"/>
        <location filename="../mainwindow.cpp" line="2702"/>
        <source>Problem detected while installing, please inspect the console output.</source>
        <translation>Ob nameščanju je bila odkrita napaka. Prosimo preverite izpis konzole.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2063"/>
        <source>About %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2068"/>
        <source>%1 License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2081"/>
        <source>%1 Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2735"/>
        <location filename="../mainwindow.cpp" line="2746"/>
        <source>More &amp;info...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2804"/>
        <source>Problem detected during last operation, please inspect the console output.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About MX Package Installer</source>
        <translation type="vanished">O programu MX Namestitev paketov</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2064"/>
        <source>Version: </source>
        <translation>Različica:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2065"/>
        <source>Package Installer for MX Linux</source>
        <translation>Namestilnik paketov za MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2067"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <source>License</source>
        <translation type="vanished">Licenca</translation>
    </message>
    <message>
        <source>Changelog</source>
        <translation type="vanished">Dnevnik sprememb</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="vanished">&amp;Zapri</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2780"/>
        <source>Reinstall</source>
        <translation>Ponovno namesti</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2169"/>
        <source>We encountered a problem uninstalling, please check output</source>
        <translation>Pri odstranjevanju se je pjavila težava. Preverite izpis konzole.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2181"/>
        <source>Success</source>
        <translation>Operacija je uspela</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2187"/>
        <source>We encountered a problem uninstalling the program</source>
        <translation>Pri odstranjevanju se je pojavila težava</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2285"/>
        <location filename="../mainwindow.cpp" line="2296"/>
        <source>Flatpak not installed</source>
        <translation>Flatpak ni bil nameščen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2285"/>
        <source>Flatpak is not currently installed.
OK to go ahead and install it?</source>
        <translation>Flatopak trenutno ni nameščen.
Ali naj ga namestim?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2296"/>
        <source>Flatpak was not installed</source>
        <translation>Flatpak ni bil namesčen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2317"/>
        <location filename="../mainwindow.cpp" line="2336"/>
        <source>Flathub remote failed</source>
        <translation>Flathub oddaljeni dostop ni uspel</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2317"/>
        <location filename="../mainwindow.cpp" line="2336"/>
        <source>Flathub remote could not be added</source>
        <translation>Flathub oddaljeni dostop ni bil dodan</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2325"/>
        <source>Needs re-login</source>
        <translation>Potreben je ponovni vpis</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2325"/>
        <source>You might need to logout/login to see installed items in the menu</source>
        <translation>Da bi videli nameščene pakete v menijih, bo morda potreben ponovni vpis</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2509"/>
        <source>Upgrade</source>
        <translation>Nadgradi</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2629"/>
        <source>Quit?</source>
        <translation>Končam?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2630"/>
        <source>Process still running, quitting might leave the system in an unstable state.&lt;p&gt;&lt;b&gt;Are you sure you want to exit MX Package Installer?&lt;/b&gt;</source>
        <translation>Proces se še izvaja, dokončanje bi lahko destabiliziralo sistem.&lt;p&gt;&lt;b&gt; Ali ste prepričani, da bi radi zaustili MX namestitev paketov?&lt;/b&gt;</translation>
    </message>
</context>
<context>
    <name>ManageRemotes</name>
    <message>
        <location filename="../remotes.cpp" line="14"/>
        <source>Manage Flatpak Remotes</source>
        <translation>Upravljaj Flatpak oddaljenih strežnikov</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="23"/>
        <source>For all users</source>
        <translation>Za vse uporabnike</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="24"/>
        <source>For current user</source>
        <translation>Za trenutnega uporabnika</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="30"/>
        <source>enter Flatpak remote URL</source>
        <translation>vnesite oddaljni URL za Flatpak</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="33"/>
        <source>enter Flatpakref location to install app</source>
        <translation>vnesite lokacijo za Flatpakref, da bi namestili app</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="35"/>
        <source>Add or remove flatpak remotes (repos), or install apps using flatpakref URL or path</source>
        <translation>Dodaj ali odstrani flatpak oddaljni dostop (repoji) ali namesti flatpakref URL ali pot</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="44"/>
        <source>Remove remote</source>
        <translation>Odstrani oddaljeni strežnik</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="49"/>
        <source>Add remote</source>
        <translation>Dodaj oddaljeni strežnik</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="54"/>
        <source>Install app</source>
        <translation>Namesti app</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="59"/>
        <source>Close</source>
        <translation>Zapri</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="76"/>
        <source>Not removable</source>
        <translation>Ni odstranljivo</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="76"/>
        <source>Flathub is the main Flatpak remote and won&apos;t be removed</source>
        <translation>Flathub je glavni Flatpak oddaljeni strežnik in ne bo odstranjen</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="92"/>
        <source>Error adding remote</source>
        <translation>Napaka pri dodajanju oddaljenega dostopa</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="92"/>
        <source>Could not add remote - command returned an error. Please double-check the remote address and try again</source>
        <translation>Neupsešno dodajanje oddaljenega dostopa - ukaz je vrnil napako. Preverite naslov oddaljenega strežnika in poskusite znova</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="96"/>
        <source>Success</source>
        <translation>Operacija je uspela</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="96"/>
        <source>Remote added successfully</source>
        <translation>Oddaljeni strežnik je bil uspešno dodan</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>Unable to get exclusive lock</source>
        <translation type="vanished">Ekskluzivni zaklep ni mogoč</translation>
    </message>
    <message>
        <source>Another package management application (like Synaptic or apt-get), is already running. Please close that application first</source>
        <translation type="vanished">Zagnana je še ena aplikacija za nameščanje programov (kot sta Synaptic ali apt-get). Zaprite najprej to aplikacijo</translation>
    </message>
    <message>
        <source>You must run this program as root.</source>
        <translation type="vanished">Ta program morate zagnati kot root</translation>
    </message>
    <message>
        <source>License</source>
        <translation type="obsolete">Licenca</translation>
    </message>
    <message>
        <source>Changelog</source>
        <translation type="obsolete">Dnevnik sprememb</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="obsolete">Prekini</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="obsolete">&amp;Zapri</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="32"/>
        <source>License</source>
        <translation type="unfinished">Licenca</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="33"/>
        <location filename="../about.cpp" line="43"/>
        <source>Changelog</source>
        <translation type="unfinished">Dnevnik sprememb</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="34"/>
        <source>Cancel</source>
        <translation type="unfinished">Prekini</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="51"/>
        <source>&amp;Close</source>
        <translation type="unfinished">&amp;Zapri</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="63"/>
        <source>Error</source>
        <translation type="unfinished">Napaka</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="64"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="73"/>
        <source>Unable to get exclusive lock</source>
        <translation type="unfinished">Ekskluzivni zaklep ni mogoč</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <source>Another package management application (like Synaptic or apt-get), is already running. Please close that application first</source>
        <translation type="unfinished">Zagnana je še ena aplikacija za nameščanje programov (kot sta Synaptic ali apt-get). Zaprite najprej to aplikacijo</translation>
    </message>
</context>
</TS>
